/****************************************************************************
** Meta object code from reading C++ file 'org_deepin_dde_gesture1.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "org_deepin_dde_gesture1.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'org_deepin_dde_gesture1.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN31__OrgDeepinDdeGesture1InterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto __OrgDeepinDdeGesture1Interface::qt_create_metaobjectdata<qt_meta_tag_ZN31__OrgDeepinDdeGesture1InterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__OrgDeepinDdeGesture1Interface",
        "TouchEdgeEvent",
        "",
        "direction",
        "scalex",
        "scaley",
        "TouchMoving",
        "TouchPressTimeout",
        "fingers",
        "time",
        "TouchSinglePressTimeout",
        "TouchUpOrCancel",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'TouchEdgeEvent'
        QtMocHelpers::SignalData<void(const QString &, double, double)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Double, 4 }, { QMetaType::Double, 5 },
        }}),
        // Signal 'TouchMoving'
        QtMocHelpers::SignalData<void(double, double)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 4 }, { QMetaType::Double, 5 },
        }}),
        // Signal 'TouchPressTimeout'
        QtMocHelpers::SignalData<void(int, int, double, double)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { QMetaType::Int, 9 }, { QMetaType::Double, 4 }, { QMetaType::Double, 5 },
        }}),
        // Signal 'TouchSinglePressTimeout'
        QtMocHelpers::SignalData<void(int, double, double)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 }, { QMetaType::Double, 4 }, { QMetaType::Double, 5 },
        }}),
        // Signal 'TouchUpOrCancel'
        QtMocHelpers::SignalData<void(double, double)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 4 }, { QMetaType::Double, 5 },
        }}),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__OrgDeepinDdeGesture1Interface, qt_meta_tag_ZN31__OrgDeepinDdeGesture1InterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __OrgDeepinDdeGesture1Interface::staticMetaObject = { {
    QMetaObject::SuperData::link<DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31__OrgDeepinDdeGesture1InterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31__OrgDeepinDdeGesture1InterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN31__OrgDeepinDdeGesture1InterfaceE_t>.metaTypes,
    nullptr
} };

void __OrgDeepinDdeGesture1Interface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__OrgDeepinDdeGesture1Interface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->TouchEdgeEvent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 1: _t->TouchMoving((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 2: _t->TouchPressTimeout((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4]))); break;
        case 3: _t->TouchSinglePressTimeout((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 4: _t->TouchUpOrCancel((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 5: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 6: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeGesture1Interface::*)(const QString & , double , double )>(_a, &__OrgDeepinDdeGesture1Interface::TouchEdgeEvent, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeGesture1Interface::*)(double , double )>(_a, &__OrgDeepinDdeGesture1Interface::TouchMoving, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeGesture1Interface::*)(int , int , double , double )>(_a, &__OrgDeepinDdeGesture1Interface::TouchPressTimeout, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeGesture1Interface::*)(int , double , double )>(_a, &__OrgDeepinDdeGesture1Interface::TouchSinglePressTimeout, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeGesture1Interface::*)(double , double )>(_a, &__OrgDeepinDdeGesture1Interface::TouchUpOrCancel, 4))
            return;
    }
}

const QMetaObject *__OrgDeepinDdeGesture1Interface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__OrgDeepinDdeGesture1Interface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31__OrgDeepinDdeGesture1InterfaceE_t>.strings))
        return static_cast<void*>(this);
    return DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __OrgDeepinDdeGesture1Interface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void __OrgDeepinDdeGesture1Interface::TouchEdgeEvent(const QString & _t1, double _t2, double _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void __OrgDeepinDdeGesture1Interface::TouchMoving(double _t1, double _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void __OrgDeepinDdeGesture1Interface::TouchPressTimeout(int _t1, int _t2, double _t3, double _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 3
void __OrgDeepinDdeGesture1Interface::TouchSinglePressTimeout(int _t1, double _t2, double _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void __OrgDeepinDdeGesture1Interface::TouchUpOrCancel(double _t1, double _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}
QT_WARNING_POP
