/*
 * This file was generated by qdbusxml2cpp-fix version 0.8
 * Command line was: qdbusxml2cpp-fix -m -p org_deepin_dde_soundeffect1 /build/deepin-session-ui/src/dde-session-ui/xml/org.deepin.dde.SoundEffect1.xml
 *
 * qdbusxml2cpp-fix is Copyright (C) 2016 Deepin Technology Co., Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef ORG_DEEPIN_DDE_SOUNDEFFECT1_H
#define ORG_DEEPIN_DDE_SOUNDEFFECT1_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

#include <DDBusExtendedAbstractInterface>
#include <QtDBus/QtDBus>


/*
 * Proxy class for interface org.deepin.dde.SoundEffect1
 */
class __OrgDeepinDdeSoundEffect1InterfacePrivate;
class __OrgDeepinDdeSoundEffect1Interface : public DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface
{
    Q_OBJECT

public:
    static inline const char *staticInterfaceName()
    { return "org.deepin.dde.SoundEffect1"; }

public:
    explicit __OrgDeepinDdeSoundEffect1Interface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = 0);

    ~__OrgDeepinDdeSoundEffect1Interface();

    Q_PROPERTY(bool Enabled READ enabled WRITE setEnabled NOTIFY EnabledChanged)
    bool enabled();
    void setEnabled(bool value);

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> EnableSound(const QString &name, bool enabled)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(name) << QVariant::fromValue(enabled);
        return asyncCallWithArgumentList(QStringLiteral("EnableSound"), argumentList);
    }

    inline void EnableSoundQueued(const QString &name, bool enabled)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(name) << QVariant::fromValue(enabled);

        CallQueued(QStringLiteral("EnableSound"), argumentList);
    }


    inline QDBusPendingReply<QMap<QString,bool> > GetSoundEnabledMap()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("GetSoundEnabledMap"), argumentList);
    }



    inline QDBusPendingReply<QString> GetSoundFile(const QString &name)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(name);
        return asyncCallWithArgumentList(QStringLiteral("GetSoundFile"), argumentList);
    }



    inline QDBusPendingReply<QString> GetSystemSoundFile(const QString &name)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(name);
        return asyncCallWithArgumentList(QStringLiteral("GetSystemSoundFile"), argumentList);
    }



    inline QDBusPendingReply<bool> IsSoundEnabled(const QString &name)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(name);
        return asyncCallWithArgumentList(QStringLiteral("IsSoundEnabled"), argumentList);
    }



    inline QDBusPendingReply<> PlaySound(const QString &name)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(name);
        return asyncCallWithArgumentList(QStringLiteral("PlaySound"), argumentList);
    }

    inline void PlaySoundQueued(const QString &name)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(name);

        CallQueued(QStringLiteral("PlaySound"), argumentList);
    }


    inline QDBusPendingReply<> PlaySystemSound(const QString &name)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(name);
        return asyncCallWithArgumentList(QStringLiteral("PlaySystemSound"), argumentList);
    }

    inline void PlaySystemSoundQueued(const QString &name)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(name);

        CallQueued(QStringLiteral("PlaySystemSound"), argumentList);
    }



Q_SIGNALS: // SIGNALS
    // begin property changed signals
    void EnabledChanged(bool  value) const;

public Q_SLOTS:
    void CallQueued(const QString &callName, const QList<QVariant> &args);

private Q_SLOTS:
    void onPendingCallFinished(QDBusPendingCallWatcher *w);
    void onPropertyChanged(const QString &propName, const QVariant &value);

private:
    __OrgDeepinDdeSoundEffect1InterfacePrivate *d_ptr;
};

namespace org {
  namespace deepin {
    namespace dde {
      typedef ::__OrgDeepinDdeSoundEffect1Interface SoundEffect1;
    }
  }
}
#endif
