/*
 * This file was generated by qdbusxml2cpp-fix version 0.8
 * Command line was: qdbusxml2cpp-fix -m -p com_deepin_chromeextension_tabslimit /build/deepin-session-ui/src/dde-session-ui/xml/com.deepin.chromeExtension.TabsLimit.xml
 *
 * qdbusxml2cpp-fix is Copyright (C) 2016 Deepin Technology Co., Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef COM_DEEPIN_CHROMEEXTENSION_TABSLIMIT_H
#define COM_DEEPIN_CHROMEEXTENSION_TABSLIMIT_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

#include <DDBusExtendedAbstractInterface>
#include <QtDBus/QtDBus>


/*
 * Proxy class for interface com.deepin.chromeExtension.TabsLimit
 */
class __ComDeepinChromeExtensionTabsLimitInterfacePrivate;
class __ComDeepinChromeExtensionTabsLimitInterface : public DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface
{
    Q_OBJECT

public:
    static inline const char *staticInterfaceName()
    { return "com.deepin.chromeExtension.TabsLimit"; }

public:
    explicit __ComDeepinChromeExtensionTabsLimitInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = 0);

    ~__ComDeepinChromeExtensionTabsLimitInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> CloseTab(int in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("CloseTab"), argumentList);
    }

    inline void CloseTabQueued(int in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("CloseTab"), argumentList);
    }


    inline QDBusPendingReply<QString> GetProcessInfo()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("GetProcessInfo"), argumentList);
    }



    inline QDBusPendingReply<> OpenUrl(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("OpenUrl"), argumentList);
    }

    inline void OpenUrlQueued(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("OpenUrl"), argumentList);
    }



Q_SIGNALS: // SIGNALS
    // begin property changed signals

public Q_SLOTS:
    void CallQueued(const QString &callName, const QList<QVariant> &args);

private Q_SLOTS:
    void onPendingCallFinished(QDBusPendingCallWatcher *w);

private:
    __ComDeepinChromeExtensionTabsLimitInterfacePrivate *d_ptr;
};

namespace com {
  namespace deepin {
    namespace chromeextension {
      typedef ::__ComDeepinChromeExtensionTabsLimitInterface TabsLimit;
    }
  }
}
#endif
