/****************************************************************************
** Meta object code from reading C++ file 'org_deepin_dde_accounts1.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "org_deepin_dde_accounts1.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'org_deepin_dde_accounts1.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN32__OrgDeepinDdeAccounts1InterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto __OrgDeepinDdeAccounts1Interface::qt_create_metaobjectdata<qt_meta_tag_ZN32__OrgDeepinDdeAccounts1InterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__OrgDeepinDdeAccounts1Interface",
        "UserAdded",
        "",
        "in0",
        "UserDeleted",
        "AllowGuestChanged",
        "value",
        "GuestIconChanged",
        "UserListChanged",
        "AllowGuestAccount",
        "QDBusPendingReply<>",
        "AllowGuestAccountQueued",
        "CreateGuestAccount",
        "QDBusPendingReply<QString>",
        "CreateUser",
        "QDBusPendingReply<QDBusObjectPath>",
        "in1",
        "in2",
        "DeleteUser",
        "DeleteUserQueued",
        "FindUserById",
        "FindUserByName",
        "GetGroups",
        "QDBusPendingReply<QStringList>",
        "GetPresetGroups",
        "IsPasswordValid",
        "QDBusPendingReply<bool,QString,int>",
        "QDBusReply<bool>",
        "QString&",
        "out1",
        "int&",
        "out2",
        "IsUsernameValid",
        "RandUserIcon",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onPropertyChanged",
        "propName",
        "QVariant",
        "AllowGuest",
        "GuestIcon",
        "UserList"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'UserAdded'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'UserDeleted'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'AllowGuestChanged'
        QtMocHelpers::SignalData<void(bool) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'GuestIconChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'UserListChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 6 },
        }}),
        // Slot 'AllowGuestAccount'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(9, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'AllowGuestAccountQueued'
        QtMocHelpers::SlotData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'CreateGuestAccount'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(12, 2, QMC::AccessPublic, 0x80000000 | 13),
        // Slot 'CreateUser'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &, const QString &, int)>(14, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 16 }, { QMetaType::Int, 17 },
        }}),
        // Slot 'DeleteUser'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, bool)>(18, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 16 },
        }}),
        // Slot 'DeleteUserQueued'
        QtMocHelpers::SlotData<void(const QString &, bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 16 },
        }}),
        // Slot 'FindUserById'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(20, 2, QMC::AccessPublic, 0x80000000 | 13, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'FindUserByName'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(21, 2, QMC::AccessPublic, 0x80000000 | 13, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'GetGroups'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(22, 2, QMC::AccessPublic, 0x80000000 | 23),
        // Slot 'GetPresetGroups'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(int)>(24, 2, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'IsPasswordValid'
        QtMocHelpers::SlotData<QDBusPendingReply<bool,QString,int>(const QString &)>(25, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'IsPasswordValid'
        QtMocHelpers::SlotData<QDBusReply<bool>(const QString &, QString &, int &)>(25, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 28, 29 }, { 0x80000000 | 30, 31 },
        }}),
        // Slot 'IsUsernameValid'
        QtMocHelpers::SlotData<QDBusPendingReply<bool,QString,int>(const QString &)>(32, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'IsUsernameValid'
        QtMocHelpers::SlotData<QDBusReply<bool>(const QString &, QString &, int &)>(32, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 28, 29 }, { 0x80000000 | 30, 31 },
        }}),
        // Slot 'RandUserIcon'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(33, 2, QMC::AccessPublic, 0x80000000 | 13),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 35 }, { 0x80000000 | 36, 37 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 39, 40 },
        }}),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 42 }, { 0x80000000 | 43, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'AllowGuest'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'GuestIcon'
        QtMocHelpers::PropertyData<QString>(45, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'UserList'
        QtMocHelpers::PropertyData<QStringList>(46, QMetaType::QStringList, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__OrgDeepinDdeAccounts1Interface, qt_meta_tag_ZN32__OrgDeepinDdeAccounts1InterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __OrgDeepinDdeAccounts1Interface::staticMetaObject = { {
    QMetaObject::SuperData::link<DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32__OrgDeepinDdeAccounts1InterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32__OrgDeepinDdeAccounts1InterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN32__OrgDeepinDdeAccounts1InterfaceE_t>.metaTypes,
    nullptr
} };

void __OrgDeepinDdeAccounts1Interface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__OrgDeepinDdeAccounts1Interface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->UserAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->UserDeleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->AllowGuestChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->GuestIconChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->UserListChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 5: { QDBusPendingReply<> _r = _t->AllowGuestAccount((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->AllowGuestAccountQueued((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: { QDBusPendingReply<QString> _r = _t->CreateGuestAccount();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<QDBusObjectPath> _r = _t->CreateUser((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<> _r = _t->DeleteUser((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->DeleteUserQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 11: { QDBusPendingReply<QString> _r = _t->FindUserById((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<QString> _r = _t->FindUserByName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<QStringList> _r = _t->GetGroups();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<QStringList> _r = _t->GetPresetGroups((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<bool,QString,int> _r = _t->IsPasswordValid((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool,QString,int>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusReply<bool> _r = _t->IsPasswordValid((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int&>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<bool,QString,int> _r = _t->IsUsernameValid((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool,QString,int>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusReply<bool> _r = _t->IsUsernameValid((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int&>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<QString> _r = _t->RandUserIcon();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 21: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 22: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAccounts1Interface::*)(const QString & )>(_a, &__OrgDeepinDdeAccounts1Interface::UserAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAccounts1Interface::*)(const QString & )>(_a, &__OrgDeepinDdeAccounts1Interface::UserDeleted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAccounts1Interface::*)(bool ) const>(_a, &__OrgDeepinDdeAccounts1Interface::AllowGuestChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAccounts1Interface::*)(const QString & ) const>(_a, &__OrgDeepinDdeAccounts1Interface::GuestIconChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeAccounts1Interface::*)(const QStringList & ) const>(_a, &__OrgDeepinDdeAccounts1Interface::UserListChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->allowGuest(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->guestIcon(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->userList(); break;
        default: break;
        }
    }
}

const QMetaObject *__OrgDeepinDdeAccounts1Interface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__OrgDeepinDdeAccounts1Interface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32__OrgDeepinDdeAccounts1InterfaceE_t>.strings))
        return static_cast<void*>(this);
    return DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __OrgDeepinDdeAccounts1Interface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 23;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void __OrgDeepinDdeAccounts1Interface::UserAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void __OrgDeepinDdeAccounts1Interface::UserDeleted(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void __OrgDeepinDdeAccounts1Interface::AllowGuestChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAccounts1Interface *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void __OrgDeepinDdeAccounts1Interface::GuestIconChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAccounts1Interface *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void __OrgDeepinDdeAccounts1Interface::UserListChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeAccounts1Interface *>(this), &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
