/****************************************************************************
** Meta object code from reading C++ file 'org_deepin_dde_sessionmanager1.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "org_deepin_dde_sessionmanager1.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'org_deepin_dde_sessionmanager1.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN38__OrgDeepinDdeSessionManager1InterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto __OrgDeepinDdeSessionManager1Interface::qt_create_metaobjectdata<qt_meta_tag_ZN38__OrgDeepinDdeSessionManager1InterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__OrgDeepinDdeSessionManager1Interface",
        "Unlock",
        "",
        "CurrentUidChanged",
        "value",
        "LockedChanged",
        "StageChanged",
        "AllowSessionDaemonRun",
        "QDBusPendingReply<bool>",
        "CanHibernate",
        "CanLogout",
        "CanReboot",
        "CanShutdown",
        "CanSuspend",
        "ForceLogout",
        "QDBusPendingReply<>",
        "ForceLogoutQueued",
        "ForceReboot",
        "ForceRebootQueued",
        "ForceShutdown",
        "ForceShutdownQueued",
        "Logout",
        "LogoutQueued",
        "PowerOffChoose",
        "PowerOffChooseQueued",
        "Reboot",
        "RebootQueued",
        "Register",
        "in0",
        "RequestHibernate",
        "RequestHibernateQueued",
        "RequestLock",
        "RequestLockQueued",
        "RequestLogout",
        "RequestLogoutQueued",
        "RequestReboot",
        "RequestRebootQueued",
        "RequestShutdown",
        "RequestShutdownQueued",
        "RequestSuspend",
        "RequestSuspendQueued",
        "SetLocked",
        "SetLockedQueued",
        "Shutdown",
        "ShutdownQueued",
        "ToggleDebug",
        "ToggleDebugQueued",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onPropertyChanged",
        "propName",
        "QVariant",
        "CurrentUid",
        "Locked",
        "Stage"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Unlock'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CurrentUidChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'LockedChanged'
        QtMocHelpers::SignalData<void(bool) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'StageChanged'
        QtMocHelpers::SignalData<void(int) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'AllowSessionDaemonRun'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(7, 2, QMC::AccessPublic, 0x80000000 | 8),
        // Slot 'CanHibernate'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(9, 2, QMC::AccessPublic, 0x80000000 | 8),
        // Slot 'CanLogout'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(10, 2, QMC::AccessPublic, 0x80000000 | 8),
        // Slot 'CanReboot'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(11, 2, QMC::AccessPublic, 0x80000000 | 8),
        // Slot 'CanShutdown'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(12, 2, QMC::AccessPublic, 0x80000000 | 8),
        // Slot 'CanSuspend'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(13, 2, QMC::AccessPublic, 0x80000000 | 8),
        // Slot 'ForceLogout'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(14, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'ForceLogoutQueued'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ForceReboot'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(17, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'ForceRebootQueued'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ForceShutdown'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(19, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'ForceShutdownQueued'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Logout'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(21, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'LogoutQueued'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'PowerOffChoose'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(23, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'PowerOffChooseQueued'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Reboot'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(25, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'RebootQueued'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Register'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(27, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'RequestHibernate'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(29, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'RequestHibernateQueued'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'RequestLock'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(31, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'RequestLockQueued'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'RequestLogout'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(33, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'RequestLogoutQueued'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'RequestReboot'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(35, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'RequestRebootQueued'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'RequestShutdown'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(37, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'RequestShutdownQueued'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'RequestSuspend'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(39, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'RequestSuspendQueued'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'SetLocked'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(41, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'SetLockedQueued'
        QtMocHelpers::SlotData<void(bool)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'Shutdown'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(43, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'ShutdownQueued'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ToggleDebug'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(45, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'ToggleDebugQueued'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 48 }, { 0x80000000 | 49, 50 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 52, 53 },
        }}),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 55 }, { 0x80000000 | 56, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'CurrentUid'
        QtMocHelpers::PropertyData<QString>(57, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'Locked'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'Stage'
        QtMocHelpers::PropertyData<int>(59, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__OrgDeepinDdeSessionManager1Interface, qt_meta_tag_ZN38__OrgDeepinDdeSessionManager1InterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __OrgDeepinDdeSessionManager1Interface::staticMetaObject = { {
    QMetaObject::SuperData::link<DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38__OrgDeepinDdeSessionManager1InterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38__OrgDeepinDdeSessionManager1InterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN38__OrgDeepinDdeSessionManager1InterfaceE_t>.metaTypes,
    nullptr
} };

void __OrgDeepinDdeSessionManager1Interface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__OrgDeepinDdeSessionManager1Interface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Unlock(); break;
        case 1: _t->CurrentUidChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->LockedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->StageChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: { QDBusPendingReply<bool> _r = _t->AllowSessionDaemonRun();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<bool> _r = _t->CanHibernate();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<bool> _r = _t->CanLogout();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<bool> _r = _t->CanReboot();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<bool> _r = _t->CanShutdown();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<bool> _r = _t->CanSuspend();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->ForceLogout();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->ForceLogoutQueued(); break;
        case 12: { QDBusPendingReply<> _r = _t->ForceReboot();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->ForceRebootQueued(); break;
        case 14: { QDBusPendingReply<> _r = _t->ForceShutdown();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->ForceShutdownQueued(); break;
        case 16: { QDBusPendingReply<> _r = _t->Logout();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->LogoutQueued(); break;
        case 18: { QDBusPendingReply<> _r = _t->PowerOffChoose();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->PowerOffChooseQueued(); break;
        case 20: { QDBusPendingReply<> _r = _t->Reboot();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->RebootQueued(); break;
        case 22: { QDBusPendingReply<bool> _r = _t->Register((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<> _r = _t->RequestHibernate();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 24: _t->RequestHibernateQueued(); break;
        case 25: { QDBusPendingReply<> _r = _t->RequestLock();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->RequestLockQueued(); break;
        case 27: { QDBusPendingReply<> _r = _t->RequestLogout();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 28: _t->RequestLogoutQueued(); break;
        case 29: { QDBusPendingReply<> _r = _t->RequestReboot();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 30: _t->RequestRebootQueued(); break;
        case 31: { QDBusPendingReply<> _r = _t->RequestShutdown();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 32: _t->RequestShutdownQueued(); break;
        case 33: { QDBusPendingReply<> _r = _t->RequestSuspend();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 34: _t->RequestSuspendQueued(); break;
        case 35: { QDBusPendingReply<> _r = _t->SetLocked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 36: _t->SetLockedQueued((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: { QDBusPendingReply<> _r = _t->Shutdown();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 38: _t->ShutdownQueued(); break;
        case 39: { QDBusPendingReply<> _r = _t->ToggleDebug();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 40: _t->ToggleDebugQueued(); break;
        case 41: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 42: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 43: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeSessionManager1Interface::*)()>(_a, &__OrgDeepinDdeSessionManager1Interface::Unlock, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeSessionManager1Interface::*)(const QString & ) const>(_a, &__OrgDeepinDdeSessionManager1Interface::CurrentUidChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeSessionManager1Interface::*)(bool ) const>(_a, &__OrgDeepinDdeSessionManager1Interface::LockedChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (__OrgDeepinDdeSessionManager1Interface::*)(int ) const>(_a, &__OrgDeepinDdeSessionManager1Interface::StageChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->currentUid(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->locked(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->stage(); break;
        default: break;
        }
    }
}

const QMetaObject *__OrgDeepinDdeSessionManager1Interface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__OrgDeepinDdeSessionManager1Interface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38__OrgDeepinDdeSessionManager1InterfaceE_t>.strings))
        return static_cast<void*>(this);
    return DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __OrgDeepinDdeSessionManager1Interface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 44)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 44;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void __OrgDeepinDdeSessionManager1Interface::Unlock()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void __OrgDeepinDdeSessionManager1Interface::CurrentUidChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeSessionManager1Interface *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void __OrgDeepinDdeSessionManager1Interface::LockedChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeSessionManager1Interface *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void __OrgDeepinDdeSessionManager1Interface::StageChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< __OrgDeepinDdeSessionManager1Interface *>(this), &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
